package jp.littleforest.util;

/**
 * アサーションを行うためのユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class AssertionUtil {
    private AssertionUtil() {

    }

    /**
     * <code>arg</code> が <code>null</code> でないことをチェックします。<br />
     * 
     * @param name オブジェクト名称
     * @param arg チェック対象オブジェクト
     */
    public static void assertNotNull(final String name, final Object arg) {
        if (arg == null) {
            throw new IllegalArgumentException(name + " can't be null.");
        }
    }

    /**
     * <code>arg</code> が <code>null</code> または空文字列ではないことをチェックします。<br />
     * 
     * @param name オブジェクト名称
     * @param arg チェック対象文字列
     */
    public static void assertNotEmpty(final String name, final String arg) {
        if (arg == null || arg.length() == 0) {
            throw new IllegalArgumentException(name + " can't be empty.");
        }
    }

    /**
     * <code>arg</code> が <code>clazz</code> のサブクラスであることをチェックします。<br />
     * 
     * @param name オブジェクト名称
     * @param clazz クラス
     * @param arg チェック対象オブジェクト
     */
    public static void assertInstanceOf(final String name,
            final Class<?> clazz, final Object arg) {
        if (!clazz.isAssignableFrom(arg.getClass())) {
            throw new IllegalArgumentException(name + " must be "
                    + clazz.getName() + "'s subclass.");
        }
    }

    /**
     * 与えられた数が 0 より大きい数であることをチェックします。<br />
     * 
     * @param name 変数名
     * @param num 値
     */
    public static void assertLargerThanZero(final String name, final int num) {
        if (num < 1) {
            throw new IllegalArgumentException(name
                    + " must be larger than zero.");
        }
    }

    /**
     * 与えられた数が 0 より大きい数であることをチェックします。<br />
     * 
     * @param name 変数名
     * @param num 値
     */
    public static void assertLargerThanZero(final String name, final long num) {
        if (num < 1) {
            throw new IllegalArgumentException(name
                    + " must be larger than zero.");
        }
    }

    /**
     * 与えられた数が 0 以上の数であることをチェックします。<br />
     * 
     * @param name 変数名
     * @param num 値
     */
    public static void assertZeroOrMore(final String name, final int num) {
        if (num < 0) {
            throw new IllegalArgumentException(name + " must be zero or more.");
        }
    }

    /**
     * 与えられた数が 0 以上の数であることをチェックします。<br />
     * 
     * @param name 変数名
     * @param num 値
     */
    public static void assertZeroOrMore(final String name, final long num) {
        if (num < 0) {
            throw new IllegalArgumentException(name + " must be zero or more.");
        }
    }
}
