package jp.littleforest.util;

/**
 * プロパティを表すクラスです。<br />
 * 
 * @author y-komori
 */
public class Property {
    private static final String SEP = "=";

    private String name;

    private String value;

    /**
     * 名称と値を指定してプロパティを構築します。<br />
     * 
     * @param name
     *        名称
     * @param value
     *        値
     */
    public Property(final String name, final String value) {
        if (name == null) {
            throw new IllegalArgumentException("name cant't be null");
        }
        this.name = name;
        this.value = value;
    }

    /**
     * 「(名称)=(値)」形式の文字列からプロパティを構築します。<br />
     * 
     * @param line
     *        「(名称)=(値)」形式の文字列
     * @param trim
     *        <code>true</code> の場合、名称と値のトリムを行う
     */
    public Property(final String line, final boolean trim) {
        if (line == null) {
            throw new IllegalArgumentException("line cant't be null");
        }

        int pos = line.indexOf(SEP);
        if (pos > 0) {
            this.name = line.substring(0, pos);
            this.value = line.substring(pos + 1);

            if ("".equals(this.name.trim())) {
                throw new PropertyFormatException(line);
            }

            if (trim) {
                this.name = this.name.trim();
                this.value = this.value.trim();
            }
        } else {
            throw new PropertyFormatException(line);
        }
    }

    /**
     * 「(名称)=(値)」形式の文字列からプロパティを構築します。<br />
     * 構築時、名称と値のトリムを行います。
     * 
     * @param line
     *        「(名称)=(値)」形式の文字列
     */
    public Property(final String line) {
        this(line, true);
    }

    /**
     * プロパティ名を返します。<br />
     * 
     * @return プロパティ名
     */
    public String getName() {
        return name;
    }

    /**
     * プロパティ名を設定します。<br />
     * 
     * @param name
     *        プロパティ名
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * 値を返します。<br />
     * 
     * @return 値
     */
    public String getValue() {
        return value;
    }

    /**
     * 値を設定します。<br />
     * 
     * @param value
     *        値
     */
    public void setValue(final String value) {
        this.value = value;
    }

    /*
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        return name + SEP + value;
    }
}
