/**
 * Copyright 2009 Yusuke Komori.
 */
package jp.littleforest.util.db;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

/**
 * データベースアクセスに関するユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class DBUtil {
    private DBUtil() {

    }

    /**
     * データベースへ接続し、コネクションを取得します。<br />
     * 
     * @param driverClassName ドライバクラス名
     * @param jdbcurl JDBC URL
     * @param user ユーザ名
     * @param pass パスワード
     * @return {@link Connection} オブジェクト
     * @throws ClassNotFoundException ドライバクラスが見つからなかった場合
     * @throws SQLException 接続に失敗した場合
     */
    public static Connection createConnection(final String driverClassName,
            final String jdbcurl, final String user, final String pass)
            throws ClassNotFoundException, SQLException {
        Class.forName(driverClassName);
        return DriverManager.getConnection(jdbcurl, user, pass);
    }

    /**
     * {@link Connection} をクローズします。<br />
     * 
     * @param connection クローズする {@link Connection}。<code>null</code> でも構いません。
     */
    public static void close(final Connection connection) {
        try {
            if (connection != null) {
                connection.close();
            }
        } catch (SQLException ex) {
            // Do nothing.
        }
    }

    /**
     * {@link Statement} をクローズします。<br />
     * 
     * @param statement クローズする {@link Statement}。<code>null</code> でも構いません。
     */
    public static void close(final Statement statement) {
        try {
            if (statement != null) {
                statement.close();
            }
        } catch (SQLException ex) {
            // Do nothing.
        }
    }

    /**
     * {@link ResultSet} をクローズします。<br />
     * 
     * @param resultSet クローズする {@link ResultSet}。<code>null</code> でも構いません。
     */
    public static void close(final ResultSet resultSet) {
        try {
            if (resultSet != null) {
                resultSet.close();
            }
        } catch (SQLException ex) {
            // Do nothing.
        }
    }
}
