/**
 * Copyright 2009 Yusuke Komori. All rights reserved.
 */
package jp.littleforest.util.encode;

import static jp.littleforest.util.encode.EncodingEnum.*;

import java.io.UnsupportedEncodingException;
import java.util.Locale;

/**
 * エンコーディングを支援するユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class EncodeUtil {
    private static boolean isCp932 = false;

    private EncodeUtil() {
    }

    static {
        String p = System.getProperty("iscp932");
        String os = System.getProperty("os.name");
        if (Locale.getDefault().getLanguage().equals("ja")) {
            if (p != null && Boolean.getBoolean(p))
                isCp932 = true;
            else if (os != null
                    && (os.equals("Windows 95") || os.equals("Windows NT") || os
                            .equals("Windows XP")))
                isCp932 = true;
        }
    }

    /**
     * This method converts Cp932 to JIS.
     * 
     * @author Kazuhiro Kazama
     * @version 1.0 01/06/97
     */
    public static String toJIS(final String s) {
        if (!isCp932)
            return s;
        StringBuffer sb = new StringBuffer();
        char c;
        for (int i = 0; i < s.length(); i++) {
            c = s.charAt(i);
            switch (c) {
            case 0xff3c: // FULLWIDTH REVERSE SOLIDUS ->
                c = 0x005c; // REVERSE SOLIDUS
                break;
            case 0xff5e: // FULLWIDTH TILDE ->
                c = 0x301c; // WAVE DASH
                break;
            case 0x2225: // PARALLEL TO ->
                c = 0x2016; // DOUBLE VERTICAL LINE
                break;
            case 0xff0d: // FULLWIDTH HYPHEN-MINUS ->
                c = 0x2212; // MINUS SIGN
                break;
            case 0xffe0: // FULLWIDTH CENT SIGN ->
                c = 0x00a2; // CENT SIGN
                break;
            case 0xffe1: // FULLWIDTH POUND SIGN ->
                c = 0x00a3; // POUND SIGN
                break;
            case 0xffe2: // FULLWIDTH NOT SIGN ->
                c = 0x00ac; // NOT SIGN
                break;
            }
            sb.append(c);
        }
        return new String(sb);
    }

    /**
     * This method convert JIS to Cp932.
     * 
     * @author Kazuhiro Kazama
     * @version 1.0 01/06/97
     */
    public static String toCp932(final String s) {
        if (!isCp932)
            return s;
        StringBuffer sb = new StringBuffer();
        char c;
        for (int i = 0; i < s.length(); i++) {
            c = s.charAt(i);
            switch (c) {
            case 0x005c: // REVERSE SOLIDUS ->
                c = 0xff3c; // FULLWIDTH REVERSE SOLIDUS
                break;
            case 0x301c: // WAVE DASH ->
                c = 0xff5e; // FULLWIDTH TILDE
                break;
            case 0x2016: // DOUBLE VERTICAL LINE ->
                c = 0x2225; // PARALLEL TO
                break;
            case 0x2212: // MINUS SIGN ->
                c = 0xff0d; // FULLWIDTH HYPHEN-MINUS
                break;
            case 0x00a2: // CENT SIGN ->
                c = 0xffe0; // FULLWIDTH CENT SIGN
                break;
            case 0x00a3: // POUND SIGN ->
                c = 0xffe1; // FULLWIDTH POUND SIGN
                break;
            case 0x00ac: // NOT SIGN ->
                c = 0xffe2; // FULLWIDTH NOT SIGN
                break;
            }
            sb.append(c);
        }
        return new String(sb);
    }

    public static String convertEncode(final String target, final String charset) {
        try {
            return new String(target.getBytes(), charset);
        } catch (UnsupportedEncodingException ex) {
            return target;
        }
    }

    public static String toEuc(final String target) {
        try {
            return new String(target.getBytes(), EUC_JP.name);
        } catch (UnsupportedEncodingException ex) {
            return target;
        }
    }

    public static String getString(final byte[] bytes, final String charSet) {
        try {
            return new String(bytes, charSet);
        } catch (UnsupportedEncodingException ex) {
            return null;
        }
    }

    public static String getString(final String string, final String charSet) {
        try {
            return new String(string.getBytes(), charSet);
        } catch (UnsupportedEncodingException ex) {
            return null;
        }
    }
}
