/**
 * Copyright 2009 Yusuke Komori. All rights reserved.
 */
package jp.littleforest.util.encode;

/**
 * 各種エンコーディングを表すための列挙型です。<br />
 * 
 * @author y-komori
 */
public enum EncodingEnum {
    /** 8 ビット UCS Transformation Format。<br /> */
    UTF_8("UTF-8"),

    /**
     * * Shift-JIS、EUC-JP、ISO 2022 JP の検出および変換 (Unicode への変換のみ)。<br/>
     * (java.nioにおける正準名)
     */
    X_JIS_AUTO_DETECT("x-JISAutoDetect"),

    /**
     * Shift-JIS、EUC-JP、ISO 2022 JP の検出および変換 (Unicode への変換のみ)。<br/>
     */
    JIS_AUTO_DETECT("JISAutoDetect"),

    /** ISO 2022 形式の JIS X 0201、0208、日本語。<br /> */
    ISO_2022_JP("ISO-2022-JP"),

    /**
     * ISO 2022 形式の JIS X 0201、0208、日本語。<br />
     * (java.nioにおける正準名)
     */
    ISO2022JP("ISO2022JP"),

    /** JISX 0201、0208、0212、EUC エンコーディング、日本語。<br /> */
    EUC_JP("EUC_JP"),

    /**
     * JISX 0201、0208、0212、EUC エンコーディング、日本語。<br />
     * (java.nioにおける正準名)
     */
    EUC_JP_NIO("EUC-JP"),

    /** Shift-JIS、日本語。<br /> */
    SJIS("SJIS"),

    /**
     * Shift-JIS、日本語。<br />
     * (java.nioにおける正準名)
     */
    SHIFT_JIS("Shift_JIS"),

    /** Windows 日本語。<br /> */
    MS932("MS932"),

    /**
     * Windows 日本語。<br />
     * (java.nioにおける正準名)
     */
    WINDOWS31J("windows-31j");

    public final String name;

    private EncodingEnum(final String name) {
        this.name = name;
    }

    /*
     * @see java.lang.Enum#toString()
     */
    @Override
    public String toString() {
        return this.name;
    }
}
