package jp.littleforest.util.html.query;

import java.util.List;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import au.id.jericho.lib.html.Element;

/**
 * 要素の属性値を取得するコマンドです。<br />
 * 
 * @author y-komori
 */
public class AttrCommand implements QueryCommand {
    private static final String REGEX = "@[A-Za-z]+";

    private Pattern pattern;

    public AttrCommand() {
        this.pattern = Pattern.compile(REGEX);
    }

    /*
     * @see jp.littleforest.util.html.query.QueryCommand#matches(java.lang.Object, java.lang.String)
     */
    public boolean matches(final Object target, final String command) {
        if (target instanceof Element || target instanceof List) {
            Matcher matcher = pattern.matcher(command);
            return matcher.matches();
        } else {
            return false;
        }
    }

    /*
     * @see jp.littleforest.util.html.query.QueryCommand#process(java.lang.Object, java.lang.String)
     */
    public Object process(final Object target, final String command) {
        String attrName = command.substring(1);

        if (target instanceof Element) {
            Element element = (Element) target;
            return element.getAttributeValue(attrName);
        } else if (target instanceof List) {
            List<Element> elements = castElementList(target);
            StringBuffer buf = new StringBuffer();

            boolean first = true;
            for (Element element : elements) {
                String value = element.getAttributeValue(attrName);
                if (value != null) {
                    if (!first) {
                        buf.append(",");
                    } else {
                        first = false;
                    }
                    buf.append(value);
                }
            }

            return buf.toString();
        } else {
            return "";
        }
    }

    @SuppressWarnings("unchecked")
    private List<Element> castElementList(final Object target) {
        return (List<Element>) target;
    }
}
