package jp.littleforest.util.html.query;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import au.id.jericho.lib.html.Element;
import au.id.jericho.lib.html.Segment;

/**
 * {@link Segment} オブジェクトに対して簡易 XPath 形式でクエリを行うためのクラスです。<br />
 * 
 * @author y-komori
 */
public class HtmlQuery {
    private static final Log log = LogFactory.getLog(HtmlQuery.class);

    private static final List<QueryCommand> commandList = new ArrayList<QueryCommand>();

    static {
        commandList.add(new AllElementCommand());
        commandList.add(new AttrCommand());
        commandList.add(new TextCommand());
        commandList.add(new ChildElementCommand());
        commandList.add(new CurrentCommand());
        commandList.add(new ParentCommand());
        commandList.add(new ElementCommand());
    }

    public static Object query(final Segment segment, String query) {
        if (segment == null || query == null) {
            return null;
        }

        if (query.startsWith("//")) {
            query = AllElementCommand.ALL_ELEMENT_COMMAND_STR
                    + query.substring(1);
        }
        String[] commands = query.split("/");

        Object next = segment;
        for (int i = 0; i < commands.length; i++) {
            Object result = processCommand(next, commands[i]);
            if (result != null) {
                next = result;
            } else {
                logQueryFailed(segment, query);
                return null;
            }
        }
        return next;
    }

    public static String queryString(final Segment segment, final String query) {
        Object result = query(segment, query);
        if (result != null && result instanceof String) {
            return (String) result;
        } else {
            logQueryFailed(segment, query);
            return null;
        }
    }

    @SuppressWarnings("unchecked")
    public static List<Element> queryElements(final Segment segment,
            final String query) {
        Object result = query(segment, query);
        if (result != null && result instanceof List) {
            return (List<Element>) result;
        } else {
            return new ArrayList<Element>(0);
        }
    }

    @SuppressWarnings("unchecked")
    public static Element queryElement(final Segment segment, final String query) {
        Object result = query(segment, query);
        if (result != null) {
            if (result instanceof List) {
                List<Element> resultList = (List<Element>) result;
                if (resultList.size() > 0) {
                    return resultList.get(0);
                } else {
                    logQueryFailed(segment, query);
                    return null;
                }
            } else if (result instanceof Element) {
                return (Element) result;
            } else {
                logQueryFailed(segment, query);
                return null;
            }
        } else {
            logQueryFailed(segment, query);
            return null;
        }
    }

    private static Object processCommand(final Object target,
            final String command) {
        for (QueryCommand queryCommand : commandList) {
            if (queryCommand.matches(target, command)) {
                return queryCommand.process(target, command);
            }
        }
        return null;

    }

    private static void logQueryFailed(final Segment segment, final String query) {
        log.warn("QueryFailed.\n   Query:" + query + "\n  Target:" + segment);
    }
}
