package jp.littleforest.util.image;

import java.io.File;

/**
 * 画像ファイルフォーマットを識別するためのユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class FileFormatDetector {
    private static final String FORMAT_PACKAGE = "jp.littleforest.util.image.format";

    private static final String FORMAT_SUFFIX = "FileFormat";

    private static final String[] FORMATS = { "WinBMP", "GIF", "JPEG", "PNG" };

    /**
     * 指定されたファイルの画像フォーマットを識別し、対応する {@link FileFormatInfo} オブジェクトを返します。<br />
     * 
     * @param file
     *            ファイル
     * @return {@link FileFormatInfo} オブジェクト。識別できなお場合は <code>null</code>。
     */
    public static FileFormatInfo detect(final File file) {
        for (int i = 0; i < FORMATS.length; i++) {
            if (FORMATS[i] != null) {
                try {
                    Class<?> clazz = Class.forName(FORMAT_PACKAGE + '.'
                            + FORMATS[i] + FORMAT_SUFFIX);
                    FileFormat fileFormat = (FileFormat) clazz.newInstance();
                    if (fileFormat.isSupport(file)) {
                        return fileFormat.getFileFormatInfo();
                    }
                } catch (ClassNotFoundException ex) {
                    FORMATS[i] = null;
                } catch (Exception ex) {
                }
            }
        }
        return null;
    }
}
