package jp.littleforest.util.image.format;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.channels.FileChannel;

import jp.littleforest.util.image.FileFormat;
import jp.littleforest.util.image.FileFormatInfo;

/**
 * {@link FileFormat} のための基底クラスです。<br />
 * 
 * @author y-komori
 */
public abstract class AbstractFileFormat implements FileFormat, FileFormatInfo {

    private FileChannel channel;

    /*
     * @see jp.littleforest.util.image.FileFormat#getFileFormatInfo()
     */
    public FileFormatInfo getFileFormatInfo() {
        return this;
    }

    protected ByteBuffer getByteBuffer(final File file) throws IOException {
        FileInputStream fis = new FileInputStream(file);
        channel = fis.getChannel();
        return channel.map(FileChannel.MapMode.READ_ONLY, 0, (int) channel
                .size());
    }

    protected void close() {
        if (channel != null) {
            try {
                channel.close();
            } catch (IOException ex) {
                // Do nothing.
            }
        }
    }
}
