package jp.littleforest.util.image.format;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import jp.littleforest.util.image.FileFormat;

import org.eclipse.swt.SWT;

/**
 * GIF 形式のための {@link FileFormat} です。<br />
 * 
 * @author y-komori
 */
public class GIFFileFormat extends AbstractFileFormat {
    private static final String GIF_ID = "GIF";

    private static final String GIF_87A = "87a";

    private static final String GIF_89A = "89a";

    private String gifVersion;

    /*
     * @see jp.littleforest.util.image.FileFormat#isSupport(java.io.File)
     */
    public boolean isSupport(final File file) throws IOException {
        ByteBuffer buf = getByteBuffer(file);
        buf.order(ByteOrder.LITTLE_ENDIAN);

        byte[] id = new byte[3];
        byte[] ver = new byte[3];
        buf.get(id);
        buf.get(ver);

        String idStr = new String(id);
        String verStr = new String(ver);

        boolean result = false;

        if (idStr.equals(GIF_ID)) {
            if (verStr.equals(GIF_87A)) {
                gifVersion = GIF_87A;
                result = true;
            } else if (verStr.equals(GIF_89A)) {
                gifVersion = GIF_89A;
                result = true;
            }
        }

        close();

        return result;
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getContentType()
     */
    public String getContentType() {
        return "image/gif";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getExtension()
     */
    public String getExtension() {
        return "gif";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getFormatName()
     */
    public String getFormatName() {
        return "GIF " + gifVersion;
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getSwtFormatType()
     */
    public int getSwtFormatType() {
        return SWT.IMAGE_GIF;
    }

}
