package jp.littleforest.util.image.format;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import jp.littleforest.util.image.FileFormat;

import org.eclipse.swt.SWT;

/**
 * JPEG 形式のための {@link FileFormat} です。<br />
 * 
 * @author y-komori
 */
public class JPEGFileFormat extends AbstractFileFormat {
    private static final short SOI_SEGMENT_MARKER = (short) 0xffd8;

    /*
     * @see jp.littleforest.util.image.FileFormat#isSupport(java.io.File)
     */
    public boolean isSupport(final File file) throws IOException {
        ByteBuffer buf = getByteBuffer(file);
        buf.order(ByteOrder.BIG_ENDIAN);

        short soiSeg = buf.getShort();
        close();
        return soiSeg == SOI_SEGMENT_MARKER ? true : false;
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getContentType()
     */
    public String getContentType() {
        return "image/jpeg";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getExtension()
     */
    public String getExtension() {
        return "jpg";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getFormatName()
     */
    public String getFormatName() {
        return "JPEG";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getSwtFormatType()
     */
    public int getSwtFormatType() {
        return SWT.IMAGE_JPEG;
    }

}
