package jp.littleforest.util.image.format;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.util.Arrays;

import jp.littleforest.util.image.FileFormat;

import org.eclipse.swt.SWT;

/**
 * PNG 形式のための {@link FileFormat} です。<br />
 * 
 * @author y-komori
 */
public class PNGFileFormat extends AbstractFileFormat {

    private static final byte[] PNG_SIGNATURE = new byte[] { (byte) 0x89, 0x50,
            0x4E, 0x47, 0x0D, 0x0A, 0x1A, 0x0A };

    /*
     * @see jp.littleforest.util.image.FileFormat#isSupport(java.io.File)
     */
    public boolean isSupport(final File file) throws IOException {
        ByteBuffer buf = getByteBuffer(file);

        byte[] sig = new byte[PNG_SIGNATURE.length];
        buf.get(sig);
        close();

        if (Arrays.equals(PNG_SIGNATURE, sig)) {
            return true;
        } else {
            return false;
        }
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getContentType()
     */
    public String getContentType() {
        return "image/png";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getExtension()
     */
    public String getExtension() {
        return "png";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getFormatName()
     */
    public String getFormatName() {
        return "PNG";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getSwtFormatType()
     */
    public int getSwtFormatType() {
        return SWT.IMAGE_PNG;
    }
}
