package jp.littleforest.util.image.format;

import java.io.File;
import java.io.IOException;
import java.nio.ByteBuffer;
import java.nio.ByteOrder;

import jp.littleforest.util.image.FileFormat;

import org.eclipse.swt.SWT;

/**
 * WindowsBMP 形式のための {@link FileFormat} です。<br />
 * 
 * @author y-komori
 */
public class WinBMPFileFormat extends AbstractFileFormat {
    private static final int WINDOWS_V3_HEADER_SIZE = 40;

    /*
     * @see jp.littleforest.util.image.FileFormat#isSupport(java.io.File)
     */
    public boolean isSupport(final File file) throws IOException {
        ByteBuffer buf = getByteBuffer(file);
        buf.order(ByteOrder.LITTLE_ENDIAN);

        byte first = buf.get();
        byte second = buf.get();
        buf.position(14);
        int headerSize = buf.getInt();

        if (first == 'B' && second == 'M'
                && headerSize == WINDOWS_V3_HEADER_SIZE) {
            close();
            return true;
        } else {
            close();
            return false;
        }
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getContentType()
     */
    public String getContentType() {
        return "image/bmp";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getExtension()
     */
    public String getExtension() {
        return "bmp";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getFormatName()
     */
    public String getFormatName() {
        return "WindowsBMP";
    }

    /*
     * @see jp.littleforest.util.image.FileFormatInfo#getSwtFormatType()
     */
    public int getSwtFormatType() {
        return SWT.IMAGE_BMP;
    }
}
