package jp.littleforest.util.image.impl;

import jp.littleforest.util.image.Scaler;

import org.eclipse.swt.graphics.ImageData;

/**
 * バイリニア法によるスケーラです。<br />
 * 
 * @author y-komori
 */
public class BiLinearScaler implements Scaler {

    /*
     * @see
     * jp.littleforest.util.image.Scaler#scaleImage(org.eclipse.swt.graphics
     * .ImageData, float, float)
     */
    public ImageData scaleImage(final ImageData image, final float xScale,
            final float yScale) {
        if (image == null) {
            throw new IllegalArgumentException("image can't be null");
        }

        ImageData dst = new ImageData((int) (image.width * xScale),
                (int) (image.height * yScale), image.depth, image.palette);
        for (int y = 0; y < dst.height; y++) {
            for (int x = 0; x < dst.width; x++) {
                int x0 = (int) (x / xScale);
                int y0 = (int) (y / yScale);

                if (x0 < (image.width - 1) && y0 < (image.height - 1)) {
                    // 左上の画素との距離
                    double a = x / xScale - x0;
                    double b = y / yScale - y0;

                    int newcolor = 0;
                    int color[] = new int[4];

                    color[0] = image.getPixel(x0, y0);
                    color[1] = image.getPixel(x0 + 1, y0);
                    color[2] = image.getPixel(x0, y0 + 1);
                    color[3] = image.getPixel(x0 + 1, y0 + 1);

                    // Color Element
                    int cElement[] = new int[4];

                    for (int k = 0; k < 3; k++) {
                        for (int i = 0; i < 4; i++) {
                            cElement[i] = (color[i] >> 8 * k) & 0x00ff;
                        }

                        // Xの距離×Yの距離を各画素の重みとする
                        int new_element = (int) Math.round((1 - a) * (1 - b)
                                * cElement[0] + a * (1 - b) * cElement[1]
                                + (1 - a) * b * cElement[2] + a * b
                                * cElement[3]);
                        newcolor += (new_element << 8 * k);
                    }

                    dst.setPixel(x, y, newcolor);
                }
            }
        }

        return dst;
    }
}
