package jp.littleforest.util.image.impl;

import jp.littleforest.util.image.Scaler;

import org.eclipse.swt.graphics.ImageData;

/**
 * Lanczos(ランツォシュ)補間法によるスケーリングを行うクラスです。<br />
 * 
 * @author y-komori
 */
public class LanczosScaler implements Scaler {

    /*
     * @see
     * jp.littleforest.util.image.Scaler#scaleImage(org.eclipse.swt.graphics
     * .ImageData, float, float)
     */
    public ImageData scaleImage(final ImageData image, final float xScale,
            final float yScale) {
        if (image == null) {
            throw new IllegalArgumentException("image can't be null");
        }

        ImageData dst = new ImageData((int) (image.width * xScale),
                (int) (image.height * yScale), image.depth, image.palette);

        int n = 2;
        // N値
        int nx = n - 1;
        for (int y = 0; y < dst.height; y++) {
            for (int x = 0; x < dst.width; x++) {
                double x0 = x / xScale;
                double y0 = y / yScale;
                int xBase = (int) x0;
                int yBase = (int) y0;
                int color = 0;

                double colorElement[] = new double[3];
                colorElement[0] = 0.0;
                colorElement[1] = 0.0;
                colorElement[2] = 0.0;
                double wTotal = 0.0;

                // 周辺(a*2)^2画素を取得して処理
                for (int i = -nx; i <= n; i++) {
                    for (int j = -nx; j <= n; j++) {
                        int xCurrent = xBase + i;
                        int yCurrent = yBase + j;

                        // ランツォシュの処理範囲かどうかをチェック
                        if (xCurrent < 0 || image.width <= xCurrent
                                || yCurrent < 0 || image.height <= yCurrent) {
                            continue;
                        }

                        // 距離決定
                        double distX = Math.abs(xCurrent - x0);
                        double distY = Math.abs(yCurrent - y0);
                        // 重み付け
                        double weight = 0.0;
                        if (distX == 0.0) {
                            weight = 1.0;
                        } else if (distX < n) {
                            double dPIx = Math.PI * distX;
                            weight = (Math.sin(dPIx) * Math.sin(dPIx / n))
                                    / (dPIx * (dPIx / n));
                        } else {
                            continue;
                        }
                        if (distY == 0.0) {
                            ;
                        } else if (distY < n) {
                            double dPIy = Math.PI * distY;
                            weight *= (Math.sin(dPIy) * Math.sin(dPIy / n))
                                    / (dPIy * (dPIy / n));
                        } else {
                            continue;
                        }

                        // 画素取得
                        int colorProcess = image.getPixel(xCurrent, yCurrent);
                        for (int k = 0; k < 3; k++) {
                            colorElement[k] += ((colorProcess >> k * 8) & 0xff)
                                    * weight;
                        }
                        wTotal += weight;
                    }
                }
                for (int i = 0; i < 3; i++) {
                    if (wTotal != 0)
                        colorElement[i] /= wTotal;
                    colorElement[i] = (colorElement[i] > 255) ? 255
                            : (colorElement[i] < 0) ? 0 : colorElement[i];
                    color += (int) colorElement[i] << i * 8;
                }

                dst.setPixel(x, y, color);
            }
        }
        return dst;
    }
}
