package jp.littleforest.util.io;

import java.nio.ByteBuffer;

/**
 * バイト配列のためのユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class BytesUtil {
    /**
     * バイト配列を16進数表記に変換します。<br />
     * 
     * @param bytes
     *        バイト配列
     * @param capital
     *        <code>true</code> の場合、大文字で出力します。<br />
     * @return 変換結果
     */
    public static String bytesToHexString(final byte[] bytes,
            final boolean capital) {
        if (bytes == null) {
            return null;
        }

        StringBuffer result = new StringBuffer();

        for (int i = 0; i < bytes.length; i++) {
            int digit = bytes[i];
            if (digit < 0) {
                digit += 256;
            }
            if (digit < 16) {
                result.append("0");
            }
            String value = Integer.toString(digit, 16);
            if (capital) {
                value = value.toUpperCase();
            }
            result.append(value);
        }
        return result.toString();
    }

    /**
     * バイト配列を16進数表記に変換します。<br />
     * 
     * @param bytes
     *        バイト配列
     * @return 変換結果(小文字)
     */
    public static String bytesToHexString(final byte[] bytes) {
        return bytesToHexString(bytes, false);
    }

    /**
     * 16進数表記の文字列をバイト配列に変換します。<br />
     * 
     * @param str
     *        文字列
     * @return バイト配列
     */
    public static byte[] hexStringToBytes(final String str) {
        if (str == null) {
            return null;
        }

        int length = str.length();
        if ((length % 2) != 0) {
            throw new IllegalArgumentException(
                    "String's length must be even number.");
        }
        ByteBuffer buf = ByteBuffer.allocate(length / 2);

        for (int pos = 0; pos < length; pos += 2) {
            String valStr = str.substring(pos, pos + 2);
            byte value = (byte) (Integer.parseInt(valStr, 16));
            buf.put(value);
        }

        return buf.array();
    }

    /**
     * int 型の数値をバイト配列に変換します。<br />
     * 
     * @param value
     *        値
     * @return 変換結果
     */
    public static byte[] integerToByteArray(int value) {
        byte[] array = new byte[4];
        array[3] = (byte) (value & 0x00ff);
        value = value >>> 8;
        array[2] = (byte) (value & 0x00ff);
        value = value >>> 8;
        array[1] = (byte) (value & 0x00ff);
        value = value >>> 8;
        array[0] = (byte) (value & 0x00ff);

        return array;
    }
}
