package jp.littleforest.util.io;

/**
 * システムプロパティに関する情報を取得するためのユーティリティクラスです。<br />
 * 
 * @author y-komori
 */
public class SystemUtil {
    private SystemUtil() {

    }

    public static final String OS_WINDOWS = "Windows";

    public static final String OS_LINUX = "Linux";

    /**
     * OS の名前を返します。<br />
     * 
     * @return OS の名前
     */
    public static String getOSName() {
        return System.getProperty("os.name");
    }

    /**
     * 現在の OS が Windows 系であるかどうかを返します。<br />
     * 
     * @return Windows 系であれば <code>true</code>
     */
    public static boolean isOsWindows() {
        return getOSName().startsWith(OS_WINDOWS);
    }

    /**
     * 現在の OS が Linux 系であるかどうかを返します。<br />
     * 
     * @return Linux 系であれば <code>true</code>
     */
    public static boolean isOsLinux() {
        return getOSName().startsWith(OS_LINUX);
    }

    /**
     * ファイル区切り文字を返します。<br />
     * 
     * @return ファイル区切り文字
     */
    public static String getFileSeparator() {
        return System.getProperty("file.separator");
    }

    /**
     * クラスパス区切り文字を返します。<br />
     * 
     * @return クラスパス区切り文字
     */
    public static String getPathSeparator() {
        return System.getProperty("path.separator");
    }

    /**
     * 行区切り文字を返します。<br />
     * 
     * @return 行区切り文字
     */
    public static String getLineSeparator() {
        return System.getProperty("line.separator");
    }

    /**
     * デフォルト一時ファイルのパスを返します。<br />
     * 
     * @return デフォルト一時ファイルのパス
     */
    public static String getTmpdir() {
        return System.getProperty("java.io.tmpdir");
    }

    /**
     * ユーザーのアカウント名を返します。<br />
     * 
     * @return ユーザーのアカウント名
     */
    public static String getUserName() {
        return System.getProperty("user.name");
    }

    /**
     * ユーザーのホームディレクトリを返します。<br />
     * 
     * @return ユーザーのホームディレクトリ
     */
    public static String getUserHome() {
        return System.getProperty("user.home");
    }

    /**
     * ユーザーの現在の作業ディレクトリを返します。<br />
     * 
     * @return ユーザーの現在の作業ディレクトリ
     */
    public static String getUserDir() {
        return System.getProperty("user.dir");
    }
}
